ISubscriberTopicMap class abstract

Implementers

Constructors

ISubscriberTopicMap()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topics → List<String>
no setter

Methods

clear() → void
delete({required String topic, String? id}) → void
exists(String topic, String id) → bool
get(String topic) → List<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String topic, String id) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited